@@ -18,7 +18,7 @@ class Customer():
     def __init__(self, email, first_name = None, last_name = None, phone = None, risk_action = None, id = None):
         if validators.email(email):
             self.email = email
-            self.first_name = firs_name
+            self.first_name = first_name
             self.last_name = last_name
             self.phone = phone
             self.risk_action = risk_action
